#!/usr/bin/env python

from sixel import main

main()
